##
## Jidowanki geometric model
##
# All euler angles are using (z,y,x)

## ============================================================
## Frame declarations

## ------------------------------------------------------------
## base  
##
# center of wheel axis projected onto floor
frame Robot;

## The 2 lasers
##
# center of front SICK (motorized)
# original position of the laser (when it is horizontal)
frame FrontSickOrigin;
# frame that turns with the laser
frame FrontSick;
# center of rear SICK
frame RearSick;

## The pole
##
# PTU on pole
frame PlatineBase;
frame Platine;

# cameras on pole
frame CameraTopLeft;
frame CameraTopRight;

# swissranger on pole
frame Sranger;

#kinect
frame Kinect;

## ------------------------------------------------------------
## arm etc
##
#         z y
#         |/
#       R6*-x
#         |
#         * y
#         |/
#     Base*-x
#         |
# +----------+
# |          |
# |          | front
# +----------+

# mount point of robot arm
frame BaseArmRight;

# position of last link of the arm
frame R7ArmRight;

# 6DOF force sensor (wrist)
#frame Force;

# (maybe add details for the two fingers later)
frame Gripper;

# camera on arm
#frame CameraArmLeft;
#frame CameraArmRight;

#frame CameraArm;

# ============================================================
# main frame
main Robot;


# ============================================================
# Link declarations

## The origin point of the measurements of the laser is at
##  0.063 m up from the base of the sensor -> 0.207+0.063=0.27
##  0.093 m front from the back of the sensor -> 0.340-0.084+0.093=.349
link {
    from      FrontSickOrigin;
    to        Robot;
    translate 0.349 0.0 0.270;
    rotate    0.0  0.0  0.0;
}

link {
   from      FrontSick;
   to        FrontSickOrigin;
   translate 0.0  0.0  0.0;
   rotate    0.0  0.0  0.0;
}

## Similar to FrontSick but it is nearer to robot center 
## on X axis of 1.2 cm  -> x = 0.349-0.012 = 0.337
link {
    from      RearSick;
    to        Robot;
    translate -0.337 0.0  0.270;
    rotate    3.1415926  0.0  0.0;
}

## Center of the axes of rotation of the PTU
##link {
##    from      PlatineBase;
##    to        Robot;
##    translate -0.117  0.0  1.708;
##    rotate    0.0  0.0  0.0;
##}
# 0.243 0.0 1.29
link {
    from      PlatineBase;
    to        Robot;
    translate 0.278  0.007  1.288;
    rotate    0.0  0.0  0.0;
}


## Center of the axes of rotation of the PTU
link {
    from      Platine;
    to        PlatineBase;
    translate 0.0  0.0  0.0;
    rotate    0.0  0.0  0.0;
}

## Approximative position of the cameras on the PTU
## (Don't know where is the optic center)
link {
    from      CameraTopLeft;
    to        Platine;
    translate 0.025    0.135  0.053;
    rotate    0.0     0.0    0.0;
}

link {
    from      CameraTopRight;
    to        Platine;
    translate 0.01   -0.135  0.053;
    rotate    0.0     0.0   0.0;
}

#   /* Sur la camera le repere est :
#    * X = oriente vers la gauche //droite
#    * Y = oriente vers le haut   //bas
#    * Z = oriente vers la scene
#    **********************************/
#   double chgmtBase[16] = {  0, 1, 0, 0, 
#			      0, 0, 1, 0,
#			      1, 0, 0, 0,
#			      0, 0, 0, 1 };
#   double chgmtBase_old[16] = {  0,  0, 1, 0, 
#				 -1,  0, 0, 0,
#				  0, -1, 0, 0,
#				  0,  0, 0, 1 };

## Approximative position of the sranger on the PTU
#link {
#    from      Sranger;
#    to        Platine;
#    translate 0.04     0.0    0.09;
#    rotate    -1.5708  0.0   -1.5708;
#}

link {
    from      Sranger;
    to        Platine;
    translate 0.04     0.0    0.09;
    rotate    1.5708  0.0   1.5708;
}

#link {
#    from      Sranger;
#    to        Platine;
#    translate 0.0    -0.09   -0.04;
#    rotate    -1.5708  -1.5708   0.0;
#}

# ============================================================
# The arm
#Old PA10
#link {
#    from      BaseArm;
#    to        Robot;
#    translate 0.186  -0.117  0.907;
#    rotate    1.5708  -1.5708  0.0;
#}
#KUKA
link {
    from      BaseArmRight;
    to        Robot;
    translate 0.165  0.18  0.907;
    rotate    0.0 1.5708  1.5708;
}


link {
    from      R7ArmRight; 
    to        BaseArmRight;
    translate 0.0  0.0  0.0;
    rotate    0.0  0.0  0.0;
}

#link {
#    from      Force;
#    to        R6Arm;
#    translate 0.0  0.0  0.100;
#    rotate    0.0  0.0  0.0;
#}

link {
    from      Gripper;
    to        R7ArmRight;
    translate 0.0  0.0  0.183;
    rotate    0.0  0.0  0.0;
}

#link {
#    from      CameraArmLeft;
#    to        R6Arm;
#    translate 0.050  0.045  0.11;
#    rotate    0.0  0.4014  0.0;
#}
#
#link {
#    from      CameraArmRight;
#    to        R6Arm;
#    translate 0.050  -0.045  0.11;
#    rotate    0.0  0.4014  0.0;
#}

#link {
#    from      CameraArm;
#    to        R6Arm;
#    translate 0.07568743861056551 -0.0033808173619759075 0.0841643734055637;
#    rotate    0.03657354859580511 0.3487667741578882 -0.006184043687864159;
#}

# ============================================================
# The kinect
#link {
#    from      Kinect;
#    to        Robot;
#    translate 0.20  0.30  1.60;
#    rotate    1.5708  0.0   1.5708;
#}

link {
    from      Kinect;
    to        Robot;
    translate -0.30  0  1.80;
    rotate    1.5708  0.0   1.80;
}
